<html>
    <body>
        <h1>Register for {{ event.name }}</h1>
        <form method="post" action=".">
            {% csrf_token %}
            {{ form.as_p }}
            <input type="submit" value="register" />
        </form>
    </body>
</html>
